@@ -1,3 +1,3 @@
-from .form import Form, InvalidFormType
+from .form import Form, InvalidFormType, NaiveForm
 from .reactions import ReactionForm, ReactionMenu, InvalidColor, ReactConfirm
 __all__ = ['form','reactions']
\ No newline at end of file
